==> payu-custom-browser-5.2.2-sources.jar: com/payu/custombrowser/CBConstant.java <==
// The MIT License (MIT)
//
// Copyright (c) 2014-2015 PayU India
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

package com.payu.custombrowser;

/**
 * Created by minie on 30/6/15.
 * Constants for analytics.
 */

public class CBConstant {


    //Event keys for CBAnalytics
    static final String PAYMENT_INITIATED = "PAYMENT_INITIATED";
    static final String CUSTOM_BROWSER = "CUSTOM_BROWSER";
    static final String NON_CUSTOM_BROWSER = "NON_CUSTOM_BROWSER";
    static final String PASSWORD = "PASSWORD_CLICK";
    static final String OTP = "OTP_CLICK";
    static final String RECEIVED_OTP_DIRECT = "RECEIVED_OTP_DIRECT";
    static final String RECEIVED_OTP_SELECTED = "RECEIVED_OTP_SELECTED";
    static final String RECEIVED_OTP_REGENERATE = "RECEIVED_OTP_REGENERATE";
    static final String RECEIVED_OTP_WEB = "RECEIVED_OTP_WEB";
    static final String REGENERATE = "REGENERATE_CLICK";
    static final String ENTER_MANUALLY = "ENTER_MANUALLY_CLICK";
    static final String APPROVED = "APPROVED_OTP";
    static final String SUCCESS = "SUCCESS_TRANSACTION";
    static final String FAILURE = "FAILURE_TRANSACTION";
    static final String TERMINATE = "TERMINATE_TRANSACTION";
    static final String JANTA_URL="https://jsbeasynet.jsbnet.in";
    static final String JANTA_DOMAIN="jsbeasynet.jsbnet.in";



}

==> payu-custom-browser-5.2.3-sources.jar: com/payu/custombrowser/CBConstant.java <==
// The MIT License (MIT)
//
// Copyright (c) 2014-2015 PayU India
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

package com.payu.custombrowser;

/**
 * Created by minie on 30/6/15.
 * Constants for analytics.
 */

public class CBConstant {
    //Event keys for CBAnalytics
    static final String PAYMENT_INITIATED = "PAYMENT_INITIATED";
    static final String CUSTOM_BROWSER = "CUSTOM_BROWSER";
    static final String NON_CUSTOM_BROWSER = "NON_CUSTOM_BROWSER";
    static final String PASSWORD = "PASSWORD_CLICK";
    static final String OTP = "OTP_CLICK";
    static final String RECEIVED_OTP_DIRECT = "RECEIVED_OTP_DIRECT";
    static final String RECEIVED_OTP_SELECTED = "RECEIVED_OTP_SELECTED";
    static final String RECEIVED_OTP_REGENERATE = "RECEIVED_OTP_REGENERATE";
    static final String RECEIVED_OTP_WEB = "RECEIVED_OTP_WEB";
    static final String REGENERATE = "REGENERATE_CLICK";
    static final String ENTER_MANUALLY = "ENTER_MANUALLY_CLICK";
    static final String APPROVED = "APPROVED_OTP";
    static final String SUCCESS = "SUCCESS_TRANSACTION";
    static final String FAILURE = "FAILURE_TRANSACTION";
    static final String TERMINATE = "TERMINATE_TRANSACTION";
    static final String JANTA_URL="https://jsbeasynet.jsbnet.in";
    static final String JANTA_DOMAIN="jsbeasynet.jsbnet.in";
    static final String PAYU_PREFERENCE = "PayuPreference";
    static final String DEFAULT = "default";
    static final String CARD_TOKEN = "card_token";
    static final String CVV_HASH = "cvv_hash";
    static final String CB_AUTO_APPROVE="auto_approve";
    static final String CB_AUTO_OTP_SELECT="auto_otp_select";


}
